@@ -235,11 +235,11 @@ class MediaContainer:
 
         container.course = RequestHelper.course_id_mapping[course_id]
 
-        if is_testing:
-            if container.media_type == MediaType.corrupted:
-                assert container.size == 0
-            else:
-                assert container.size != 0 and container.size != -1
+        # if is_testing:
+        #     if container.media_type == MediaType.corrupted:
+        #         assert container.size == 0
+        #     else:
+        #         assert container.size != 0 and container.size != -1
 
         return container
 
@@ -1059,7 +1059,9 @@ class CourseDownloader:
                 for item in row:
                     item._done = True
 
-            logger.done.get()
+            if not (config.telemetry_policy is False or is_testing):
+                logger.done.get()
+
             self.message_what_did_i_do(collapsed_containers)
             return
 
